==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/entity/AntSoldier.java <==
package net.invictusslayer.slayersbeasts.world.entity;

import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1366;
import net.minecraft.class_1399;
import net.minecraft.class_1400;
import net.minecraft.class_1657;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2940;
import net.minecraft.class_2943;
import net.minecraft.class_2945;
import net.minecraft.class_3730;
import net.minecraft.class_4802;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5354;
import net.minecraft.class_5819;
import net.minecraft.world.entity.*;
import org.jetbrains.annotations.Nullable;

import java.util.UUID;

public class AntSoldier extends AbstractAnt implements class_5354 {
	private static final class_2940<Integer> DATA_REMAINING_ANGER_TIME = class_2945.method_12791(AntSoldier.class, class_2943.field_13327);
	private UUID target;

	public AntSoldier(class_1299<AntSoldier> type, class_1937 level) {
		super(type, level);
	}

	protected void method_5693(class_2945.class_9222 builder) {
		super.method_5693(builder);
		builder.method_56912(DATA_REMAINING_ANGER_TIME, 0);
	}

	protected void method_5959() {
		super.method_5959();
		field_6201.method_6277(0, new class_1366(this, 1D, true));
		field_6185.method_6277(0, new class_1399(this));
		field_6185.method_6277(1, new class_1400<>(this, class_1657.class, 10, false, false, this::method_29515));
		field_6185.method_6277(2, new class_1400<>(this, class_1308.class, 10, false, true, this::method_29515));
	}

	public static class_5132.class_5133 createAttributes() {
		return method_26828()
				.method_26868(class_5134.field_23719, 0.22D)
				.method_26868(class_5134.field_23716, 15D)
				.method_26868(class_5134.field_23721, 5D)
				.method_26868(class_5134.field_23718, 0.5D);
	}

	public static boolean canSpawn(class_1299<AntSoldier> entity, class_1936 level, class_3730 spawnType, class_2338 pos, class_5819 random) {
		return method_20636(entity, level, spawnType, pos, random);
	}

	public int method_29507() {
		return field_6011.method_12789(DATA_REMAINING_ANGER_TIME);
	}

	public void method_29514(int time) {
		field_6011.method_12778(DATA_REMAINING_ANGER_TIME, time);
	}

	public UUID method_29508() {
		return target;
	}

	public void method_29513(@Nullable UUID target) {
		this.target = target;
	}

	public void method_29509() {
		method_29514(class_4802.method_24505(30, 60).method_35008(field_5974));
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/entity/AntSoldier.java <==
package net.invictusslayer.slayersbeasts.world.entity;

import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1366;
import net.minecraft.class_1399;
import net.minecraft.class_1400;
import net.minecraft.class_1657;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2940;
import net.minecraft.class_2943;
import net.minecraft.class_2945;
import net.minecraft.class_3730;
import net.minecraft.class_4802;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5354;
import net.minecraft.class_5819;
import net.minecraft.world.entity.*;
import org.jetbrains.annotations.Nullable;

import java.util.UUID;

public class AntSoldier extends AbstractAnt implements class_5354 {
	private static final class_2940<Integer> DATA_REMAINING_ANGER_TIME = class_2945.method_12791(AntSoldier.class, class_2943.field_13327);
	private UUID target;

	public AntSoldier(class_1299<AntSoldier> type, class_1937 level) {
		super(type, level);
	}

	protected void method_5693(class_2945.class_9222 builder) {
		super.method_5693(builder);
		builder.method_56912(DATA_REMAINING_ANGER_TIME, 0);
	}

	protected void method_5959() {
		super.method_5959();
		field_6201.method_6277(0, new class_1366(this, 1D, true));
		field_6185.method_6277(0, new class_1399(this));
		field_6185.method_6277(1, new class_1400<>(this, class_1657.class, 10, false, false, this::method_29515));
		field_6185.method_6277(2, new class_1400<>(this, class_1308.class, 10, false, true, this::method_29515));
	}

	public static class_5132.class_5133 createAttributes() {
		return method_26828()
				.method_26868(class_5134.field_23719, 0.22D)
				.method_26868(class_5134.field_23716, 15D)
				.method_26868(class_5134.field_23721, 5D)
				.method_26868(class_5134.field_23718, 0.5D);
	}

	public static boolean canSpawn(class_1299<AntSoldier> entity, class_1936 level, class_3730 reason, class_2338 pos, class_5819 random) {
		return method_20636(entity, level, reason, pos, random);
	}

	public int method_29507() {
		return field_6011.method_12789(DATA_REMAINING_ANGER_TIME);
	}

	public void method_29514(int time) {
		field_6011.method_12778(DATA_REMAINING_ANGER_TIME, time);
	}

	public UUID method_29508() {
		return target;
	}

	public void method_29513(@Nullable UUID target) {
		this.target = target;
	}

	public void method_29509() {
		method_29514(class_4802.method_24505(30, 60).method_35008(field_5974));
	}
}
